==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Hozzászólások",
    "Unknown user" : "Ismeretlen felhasználó",
    "New comment …" : "Új hozzászólás...",
    "Delete comment" : "Hozzászólás törlése",
    "Post" : "Küldés",
    "Cancel" : "Mégsem",
    "Edit comment" : "Hozzászólás szerkesztése",
    "[Deleted user]" : "[Törölt felhasználó]",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdd el a beszélgetést!",
    "More comments …" : "Több hozzászólás...",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with id {id}" : "Hiba a következő azonosítójú hozzászólás letöltése közben: {id}",
    "Error occurred while updating comment with id {id}" : "Hiba a következő azonosítójú hozzászólás frissítése közben: {id}",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "Comment" : "Hozzászólás",
    "You commented" : "Hozzászóltál",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászoltál ehhez: %1$s",
    "You commented on {file}" : "Hozzászóltál ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s megemlített egy hozzászólásban itt: “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlített egy hozzászólásban itt: “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Hozzászólások",
    "Unknown user" : "Ismeretlen felhasználó",
    "New comment …" : "Új hozzászólás...",
    "Delete comment" : "Hozzászólás törlése",
    "Post" : "Küldés",
    "Cancel" : "Mégsem",
    "Edit comment" : "Hozzászólás szerkesztése",
    "[Deleted user]" : "[Törölt felhasználó]",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdd el a beszélgetést!",
    "More comments …" : "Több hozzászólás...",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with id {id}" : "Hiba a következő azonosítójú hozzászólás letöltése közben: {id}",
    "Error occurred while updating comment with id {id}" : "Hiba a következő azonosítójú hozzászólás frissítése közben: {id}",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "Comment" : "Hozzászólás",
    "You commented" : "Hozzászóltál",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászoltál ehhez: %1$s",
    "You commented on {file}" : "Hozzászóltál ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “%s”, egy már törölt felhasználó hozzászólásában",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “{file}”, egy már törölt felhasználó hozzászólásában",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s megemlített egy hozzászólásban itt: “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlített egy hozzászólásban itt: “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “{file}”"
},
"nplurals=2; plural=(n != 1);");
